==> nextcloud-22.2.10.tgz: nextcloud/apps/federation/l10n/pt_PT.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis",
    "Server is already in the list of trusted servers." : "Servidor já pertence à lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor federado encontrado",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federação permite-o conectar-se a outros servidores confiáveis para troca de diretoria de utilizador.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federação permite-o conectar-se a outros servidores confiáveis para trocar a diretoria de utilizador.  Por exemplo, isto será usado para completar automaticamente utilizadores externos para partilhada federada.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A federação permite que você se conecte com outros servidores confiáveis para trocar o directório do utilizador. Isso é usado, por exemplo, para auto-completar automaticamente utlilizadores externos para partilha federada. Não é necessário adicionar um servidor como servidor confiável para criar uma partilha federada.",
    "+ Add trusted server" : "+ Adicionar servidor confiável",
    "Trusted server" : "Servidor confiável",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-23.0.5.tgz: nextcloud/apps/federation/l10n/pt_PT.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis",
    "Server is already in the list of trusted servers." : "Servidor já pertence à lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor federado encontrado",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federação permite-o conectar-se a outros servidores confiáveis para troca de diretoria de utilizador.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federação permite-o conectar-se a outros servidores confiáveis para trocar a diretoria de utilizador.  Por exemplo, isto será usado para completar automaticamente utilizadores externos para partilhada federada.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A federação permite que você se conecte com outros servidores confiáveis para trocar o directório do utilizador. Isso é usado, por exemplo, para auto-completar automaticamente utlilizadores externos para partilha federada. Não é necessário adicionar um servidor como servidor confiável para criar uma partilha federada.",
    "+ Add trusted server" : "+ Adicionar servidor confiável",
    "Trusted server" : "Servidor confiável",
    "Add" : "Adicionar"
},
"nplurals=2; plural=(n != 1);");
